/*
	File: WndIMCController.m 
	Abstract: The class that handles the interaction between the GUI and the IMCCalcul object

	Copyright (C) 2011 Laurent68k. All Rights Reserved.
 */

// we use #import to make sure the header is only read in once
#import "WndIMCController.h"

@implementation WndIMCController

@synthesize  calculator;

- (id)init {
	
    self = [super init];
    
    self->calculator = [[IMCCalcul alloc]init];
	
	return self;
}

//	Initialise l'interface avec des valeurs prédéfinies pour une adulte
-(void)InitGUIAdult {

    [tfPoids setIntValue:68];
    [tfTaille setIntValue:172];
	
    [sldPoids setIntValue:68];
    [sldTaille setIntValue:172];
    
	[stpYear setEnabled:NO];
	[stpMonth setEnabled:NO];
	
	[stpYear setIntValue:10];
	[stpMonth setIntValue:0];
	
	[lbYear setStringValue:@"10"];
	[lbMonth setStringValue:@"0"];
}

//	Initialise l'interface avec des valeurs prédéfinies pour un enfant
-(void)InitGUIEnfant {
	
    [tfPoids setIntValue:35];
    [tfTaille setIntValue:140];
	
    [sldPoids setIntValue:35];
    [sldTaille setIntValue:140];
    
	[stpYear setEnabled:YES];
	[stpMonth setEnabled:NO];			//	Pas encore implémentée...
	
	[stpYear setIntValue:10];
	[stpMonth setIntValue:0];
	
	[lbYear setStringValue:@"10"];
	[lbMonth setStringValue:@"0"];
}

// awakeFromNib is called when this object is done being unpacked from the nib file;
// at this point, we can do any needed initialization before turning app control over to the user
- (void)awakeFromNib {
	[self InitGUIAdult];
	
   	[self Calculer];
}

//	Demande de fermeture de la fenêtre, on quitte l'application
- (void)windowWillClose:(NSNotification *)note {
	
	[NSApp terminate: self ];
}

//	Slider Poids change
- (IBAction)sldPoidsChange:(id)sender {
	[tfPoids setIntValue:[sldPoids intValue]];

	[self Calculer];
}

//	Slider taille change
- (IBAction)sldTailleChange:(id)sender {
	[tfTaille setIntValue:[sldTaille intValue]];

	[self Calculer];
}

//	Sélection du type de personne
- (IBAction)rbAgeSelected:(id)sender {
	
	// cas adulte
	if( [rbMatrix selectedRow] == 0 ) {
				
		[stpYear setEnabled:NO];
		[stpMonth setEnabled:NO];
		
		[self InitGUIAdult];
		[self Calculer];
	}
	//	cas enfant fille/garcon
	else {
		
		[stpYear setEnabled:YES];
		[stpMonth setEnabled:YES];
		
		[self InitGUIEnfant];
		[self Calculer];
	}
}

//	Sur changement direct des valeurs poids/taille on change la position des sliders
- (void)controlTextDidChange:(NSNotification *)notification {
	
	//	Récupérer l'objet qui à subie le changement
	NSTextField *textField = [notification object];

	if( textField == tfPoids ) {
	
		[sldPoids setIntValue:[tfPoids intValue]];
	}
	
	if( textField == tfTaille ) {
	
		[sldTaille setIntValue:[tfTaille intValue]];
	}
	
	[self Calculer];
}

//	Changement de valeurs des steppers
- (IBAction)stepperChange:(id)sender {
	
	if( sender == stpYear ) {
		
		[lbYear setStringValue:[stpYear stringValue]];
	}
	
	if( sender == stpMonth ) {
		
		[lbMonth setStringValue:[stpMonth stringValue]];
	}

	[self Calculer];
}

//	Effectue les deux calculs et prÈsente les rÈsultats
- (void) Calculer {

	double poids, taille, seuilWarning, seuilCritical;
	int year, month;

	//	Récupérer les valeurs de l'interface
	poids = [tfPoids doubleValue];
	taille = [tfTaille doubleValue];

	year = [stpYear intValue];
	month = [stpMonth intValue];
	
	//	Type de personne
	Personne personne = Adulte;
	if( [rbMatrix selectedRow] == 1 ) {
		personne = EnfantFille;
	}
	if( [rbMatrix selectedRow] == 2 ) {
		personne = EnfantGarcon;
	}
		
	//	Effectuer les calculs
	[self->calculator Calcul:personne:year:month:poids:taille];
	[self->calculator GetSeuils:personne:year:month: &seuilWarning: &seuilCritical];

	//	Présenter les résultats
	[liIndicator setWarningValue:seuilWarning];
	[liIndicator setCriticalValue:seuilCritical];

	[tfIndice setIntValue:[self->calculator indice]];	
	[liIndicator setIntValue:[self->calculator indice]];
	
	int classification = [self->calculator categorie];
	
	switch( classification ) {
	
		case	Famine:
			[tfClassification setStringValue:@"Famine"];
			break;
			
		case	Maigreur:
			[tfClassification setStringValue:@"Maigreur"];
			break;
				
		case	Normal:
			[tfClassification setStringValue:@"Normal"];
			break;
				
		case	Surpoids:	
			[tfClassification setStringValue:@"Surpoids"];
			break;
				
		case	ObesiteModere:
			[tfClassification setStringValue:@"Obesité modérée"];
			break;
				
		case	ObesiteSevere:
			[tfClassification setStringValue:@"Obesité sévère"];
			break;

		case	ObesiteMassive:
			[tfClassification setStringValue:@"Obesité Massive"];
			break;
			
		case	ObesiteDegre1:
			[tfClassification setStringValue:@"Obesité Degré 1"];
			break;
			
		case	ObesiteDegre2:
			[tfClassification setStringValue:@"Obesité Degré 2"];
			break;
			
		default:
			[tfClassification setStringValue:@"Non calculable"];
			break;
	}
}

@end
